package controllers

import (
	"encoding/json"

	oclib "cloud.o-forge.io/core/oc-lib"
	beego "github.com/beego/beego/v2/server/web"
)

// Operations about workflow
type WorkflowController struct {
	beego.Controller
}

// @Title Update
// @Description create workflows
// @Param	body		body 	models.workflow	true		"The workflow content"
// @Success 200 {object} models.workflow
// @router / [put]
func (o *WorkflowController) Put() {
	// store and return Id or post with UUID
	var res map[string]interface{}
	id := o.Ctx.Input.Param(":id")
	json.Unmarshal(o.Ctx.Input.CopyBody(10000), &res)
	o.Data["json"] = oclib.UpdateOne(oclib.LibDataEnum(oclib.WORKFLOW), res, id)
	o.ServeJSON()
}

// @Title Create
// @Description create workflows
// @Param	data		body 	json	true		"body for data content (Json format)"
// @Success 200 {object} models.workflow
// @router / [post]
func (o *WorkflowController) Post() {
	var res map[string]interface{}
	json.Unmarshal(o.Ctx.Input.CopyBody(10000), &res)
	o.Data["json"] = oclib.StoreOne(oclib.LibDataEnum(oclib.WORKFLOW), res)
	o.ServeJSON()
}

// @Title Publish
// @Description create workflows
// @Param	id		path 	string	true		"the workflowid you want to get"
// @Success 200 {object} models.workflow
// @router /publish/:id [post]
func (o *WorkflowController) Publish() {
	id := o.Ctx.Input.Param(":id")
	data := oclib.LoadOne(oclib.LibDataEnum(oclib.WORKFLOW), id)
	if data.Data != nil {
		o.Data["json"] = oclib.CopyOne(oclib.LibDataEnum(oclib.WORKFLOW_RESOURCE), data.Data.Serialize())
	} else {
		o.Data["json"] = data
	}
	o.ServeJSON()
}

// @Title Get
// @Description find workflow by workflowid
// @Param	id		path 	string	true		"the workflowid you want to get"
// @Success 200 {workflow} models.workflow
// @router /:id [get]
func (o *WorkflowController) Get() {
	id := o.Ctx.Input.Param(":id")
	o.Data["json"] = oclib.LoadOne(oclib.LibDataEnum(oclib.WORKFLOW), id)
	o.ServeJSON()
}

// @Title Delete
// @Description delete the workflow
// @Param	id		path 	string	true		"The workflowId you want to delete"
// @Success 200 {string} delete success!
// @router /:id [delete]
func (o *WorkflowController) Delete() {
	id := o.Ctx.Input.Param(":id")
	o.Data["json"] = oclib.DeleteOne(oclib.LibDataEnum(oclib.WORKFLOW), id)
	o.ServeJSON()
}
